==> haskell-test-framework-hunit-0.3.0.2-31-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-hunit
version: 0.3.0.2
id: test-framework-hunit-0.3.0.2-2cuZrcC4fpi8ZHxh6Q4D1X
key: test-framework-hunit-0.3.0.2-2cuZrcC4fpi8ZHxh6Q4D1X
license: BSD-3-Clause
maintainer: Haskell Libraries <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: https://batterseapower.github.io/test-framework/
synopsis: HUnit support for the test-framework package.
description:
    HUnit support for the test-framework package.
category: Testing
abi: 47b4f9d45cd39006a0ceb6cbdc059e99
exposed: True
exposed-modules:
    Test.Framework.Providers.HUnit
import-dirs: /usr/lib/ghc-8.4.3/site-local/test-framework-hunit-0.3.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/test-framework-hunit-0.3.0.2
hs-libraries: HStest-framework-hunit-0.3.0.2-2cuZrcC4fpi8ZHxh6Q4D1X
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx base-4.11.1.0
    extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn
    test-framework-0.8.2.0-Goo1lQ5v8lSKQXzKjc8cO4
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn=56f3bc3a884a715c9ac7be8507078b91
             test-framework-0.8.2.0-Goo1lQ5v8lSKQXzKjc8cO4=64a691e8d693925c03bbca87367ae847
haddock-interfaces: /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock
haddock-html: /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-hunit-0.3.0.2-32-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-hunit
version: 0.3.0.2
id: test-framework-hunit-0.3.0.2-1wKogXplU49IUVucyLf4KT
key: test-framework-hunit-0.3.0.2-1wKogXplU49IUVucyLf4KT
license: BSD-3-Clause
maintainer: Haskell Libraries <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: https://batterseapower.github.io/test-framework/
synopsis: HUnit support for the test-framework package.
description:
    HUnit support for the test-framework package.
category: Testing
abi: 6ad736e777d4f469e6ac541dedcfb72e
exposed: True
exposed-modules:
    Test.Framework.Providers.HUnit
import-dirs: /usr/lib/ghc-8.6.1/site-local/test-framework-hunit-0.3.0.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/test-framework-hunit-0.3.0.2
hs-libraries: HStest-framework-hunit-0.3.0.2-1wKogXplU49IUVucyLf4KT
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj base-4.12.0.0
    extensible-exceptions-0.1.1.4-KI0dG6kQM84KnSzvR2Yb0
    test-framework-0.8.2.0-9xKSmZ6qZ74nvowfP3MHj
haddock-interfaces: /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock
haddock-html: /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
